/*
 * base64.h
 *
 * This file is part of msmtp, an SMTP client.
 *
 * This code was adapted from GNU Anubis, version 3.6.2
 * Copyright (C) 2001, 2002 The Anubis Team.
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *   msmtp is released under the GPL with the additional exemption that
 *   compiling, linking, and/or using OpenSSL is allowed.
 */

#ifndef BASE64_H
#define BASE64_H

/*
 * base64enc()
 *
 * Encode the data in 'src' (which is 'src_len' characters long) in BASE64. 
 * A pointer to the resulting string will be returned. It should be 
 * freed when not used anymore.
 * Since this function uses xmalloc(), it cannot fail.
 */
char *base64enc(const char *src, size_t src_len);

/*
 * base64dec()
 *
 * Decode the BASE64 encoded string 'src'. A pointer to the decoded data is
 * returned. It should be freed when not used anymore. The length of 
 * the decoded data is stored in 'dst_len'.
 * A return value of NULL means that 'src' is not valid base64 data.
 */
char *base64dec(const char *src, size_t *dst_len);

#endif
